@@ -281,7 +281,9 @@ static const EContactFieldInfo field_info[] = {
 	ATTR_TYPE_STR_FIELD (E_CONTACT_IM_SKYPE_WORK_1,  EVC_X_SKYPE,  "im_skype_work_1",  N_("Skype Work Name 1"),         FALSE, "WORK", 0),
 	ATTR_TYPE_STR_FIELD (E_CONTACT_IM_SKYPE_WORK_2,  EVC_X_SKYPE,  "im_skype_work_2",  N_("Skype Work Name 2"),         FALSE, "WORK", 1),
 	ATTR_TYPE_STR_FIELD (E_CONTACT_IM_SKYPE_WORK_3,  EVC_X_SKYPE,  "im_skype_work_3",  N_("Skype Work Name 3"),         FALSE, "WORK", 2),
-	MULTI_LIST_FIELD (E_CONTACT_IM_SKYPE,  	  EVC_X_SKYPE,     "im_skype",     N_("Skype Name List"),         FALSE)
+	MULTI_LIST_FIELD (E_CONTACT_IM_SKYPE,  	  EVC_X_SKYPE,     "im_skype",     N_("Skype Name List"),         FALSE),
+
+	MULTI_LIST_FIELD (E_CONTACT_SIP, 	  EVC_X_SIP,    "sip",    N_("SIP address"),          FALSE),
 };
 
 #undef LIST_ELEM_STR_FIELD
@@ -597,11 +599,11 @@ n_setter (EContact *contact, EVCardAttribute *attr, void *data)
 {
 	EContactName *name = data;
 
-	e_vcard_attribute_add_value (attr, name->family);
-	e_vcard_attribute_add_value (attr, name->given);
-	e_vcard_attribute_add_value (attr, name->additional);
-	e_vcard_attribute_add_value (attr, name->prefixes);
-	e_vcard_attribute_add_value (attr, name->suffixes);
+	e_vcard_attribute_add_value (attr, name->family ?: "");
+	e_vcard_attribute_add_value (attr, name->given ?: "");
+	e_vcard_attribute_add_value (attr, name->additional ?: "");
+	e_vcard_attribute_add_value (attr, name->prefixes ?: "");
+	e_vcard_attribute_add_value (attr, name->suffixes ?: "");
 
 	/* now find the attribute for FileAs.  if it's not present, fill it in */
 	attr = e_contact_get_first_attr (contact, EVC_X_FILE_AS);
@@ -1379,6 +1381,32 @@ e_contact_field_id (const char *field_name)
 	return 0;
 }
 
+/**
+ * e_contact_field_id_from_vcard:
+ * @vcard_field: a string representing a vCard field
+ *
+ * Gets the #EContactField corresponding to the @vcard_field.
+ *
+ * Return value: An #EContactField corresponding to @vcard_field, or %0 if it doesn't exist.
+ **/
+EContactField
+e_contact_field_id_from_vcard (const char *vcard_field)
+{
+	int i;
+
+	for (i = E_CONTACT_FIELD_FIRST; i < E_CONTACT_FIELD_LAST; i ++) {
+		if (field_info[i].vcard_field_name == NULL)
+			continue;
+		if (field_info[i].t & E_CONTACT_FIELD_TYPE_SYNTHETIC)
+			continue;
+		if (!strcmp (field_info[i].vcard_field_name, vcard_field))
+			return field_info[i].field_id;
+	}
+
+	g_warning ("unknown vCard field `%s'", vcard_field);
+	return 0;
+}
+
 /**
  * e_contact_get:
  * @contact: an #EContact
