@@ -8,7 +8,7 @@
 #include "db_config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: env_open.c 2904 2003-11-20 22:14:35Z toshok $";
+static const char revid[] = "$Id: env_open.c 8941 2008-06-06 10:43:13Z tml $";
 #endif /* not lint */
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -34,6 +34,10 @@ static const char revid[] = "$Id: env_open.c 2904 2003-11-20 22:14:35Z toshok $"
 #include "dbinc/txn.h"
 #include "dbinc/fop.h"
 
+#ifdef _WIN32
+#define strcasecmp _stricmp
+#endif
+
 static int __db_parse __P((DB_ENV *, char *));
 static int __db_tmp_open __P((DB_ENV *, u_int32_t, char *, DB_FH *));
 static int __dbenv_config __P((DB_ENV *, const char *, u_int32_t));
